@@ -4,20 +4,24 @@ TIKTOKEN_MODEL_MAPPING = {
     "gpt-4-0125-preview": "cl100k_base",
     "gpt-4-1106-preview": "cl100k_base",
     "gpt-4-1106-vision-preview": "cl100k_base",
+    "gpt-4o": "0200k_base",
 }
 
 SERVICE_PROVIDERS = {
     "ANTHROPIC": "Anthropic",
     "AZURE": "Azure",
     "CHROMA": "Chroma",
+    "GROQ": "Groq",
     "LANGCHAIN": "Langchain",
     "LANGCHAIN_COMMUNITY": "Langchain Community",
     "LANGCHAIN_CORE": "Langchain Core",
+    "LANGGRAPH": "Langgraph",
     "LLAMAINDEX": "LlamaIndex",
     "OPENAI": "OpenAI",
     "PINECONE": "Pinecone",
     "COHERE": "Cohere",
     "PPLX": "Perplexity",
+    "QDRANT": "Qdrant",
 }
 
 LANGTRACE_ADDITIONAL_SPAN_ATTRIBUTES_KEY = "langtrace_additional_attributes"
